[−][src]Enum gimli::Format
pub enum Format {
Dwarf64,
Dwarf32,
}Whether the format of a compilation unit is 32- or 64-bit.
Variants
64-bit DWARF
32-bit DWARF
Implementations
impl Format[src][−]
pub fn initial_length_size(self) -> u8[src][−]
Return the serialized size of an initial length field for the format.
pub fn word_size(self) -> u8[src][−]
Return the natural word size for the format